Cyphi.ECommerce (Cyphi v0.1.0)

Provides API endpoints related to e commerce

Summary

Types

order_crud_get_400_json_resp()

@type order_crud_get_400_json_resp() :: %{message: String.t() | nil}

order_crud_get_403_json_resp()

@type order_crud_get_403_json_resp() :: %{message: String.t() | nil}

order_crud_get_404_json_resp()

@type order_crud_get_404_json_resp() :: %{message: String.t() | nil}

order_crud_get_405_json_resp()

@type order_crud_get_405_json_resp() :: %{message: String.t() | nil}

order_crud_list_400_json_resp()

@type order_crud_list_400_json_resp() :: %{message: String.t() | nil}

order_crud_list_403_json_resp()

@type order_crud_list_403_json_resp() :: %{message: String.t() | nil}

order_crud_list_404_json_resp()

@type order_crud_list_404_json_resp() :: %{message: String.t() | nil}

order_crud_list_405_json_resp()

@type order_crud_list_405_json_resp() :: %{message: String.t() | nil}

Functions

order_crud_get(id, opts \\ [])

Get order

Return the order with the specified ID.

Options

  • $include: Comma separated list of relationships to include in the results, taken from this list: user, organization, verifier.

order_crud_list(opts \\ [])

List orders

Return a list of orders.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, organization_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, organization, verifier.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: user_id, organization_id, id. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.