Cyphi.Users (Cyphi v0.1.0)

Provides API endpoints related to users

Summary

Types

Functions

Types

user_assessment_grade_crud_get_400_json_resp()

@type user_assessment_grade_crud_get_400_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_get_403_json_resp()

@type user_assessment_grade_crud_get_403_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_get_404_json_resp()

@type user_assessment_grade_crud_get_404_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_get_405_json_resp()

@type user_assessment_grade_crud_get_405_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_list_400_json_resp()

@type user_assessment_grade_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_list_403_json_resp()

@type user_assessment_grade_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_list_404_json_resp()

@type user_assessment_grade_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_assessment_grade_crud_list_405_json_resp()

@type user_assessment_grade_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_400_json_resp()

@type user_child_crud_create_400_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_403_json_resp()

@type user_child_crud_create_403_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_404_json_resp()

@type user_child_crud_create_404_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_405_json_resp()

@type user_child_crud_create_405_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_batch_202_json_resp()

@type user_child_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}

user_child_crud_create_batch_400_json_resp()

@type user_child_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_batch_403_json_resp()

@type user_child_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_batch_404_json_resp()

@type user_child_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}

user_child_crud_create_batch_405_json_resp()

@type user_child_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}

user_child_crud_delete_400_json_resp()

@type user_child_crud_delete_400_json_resp() :: %{message: String.t() | nil}

user_child_crud_delete_403_json_resp()

@type user_child_crud_delete_403_json_resp() :: %{message: String.t() | nil}

user_child_crud_delete_404_json_resp()

@type user_child_crud_delete_404_json_resp() :: %{message: String.t() | nil}

user_child_crud_delete_405_json_resp()

@type user_child_crud_delete_405_json_resp() :: %{message: String.t() | nil}

user_child_crud_list_400_json_resp()

@type user_child_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_child_crud_list_403_json_resp()

@type user_child_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_child_crud_list_404_json_resp()

@type user_child_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_child_crud_list_405_json_resp()

@type user_child_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_course_assistant_crud_list_400_json_resp()

@type user_course_assistant_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_course_assistant_crud_list_403_json_resp()

@type user_course_assistant_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_course_assistant_crud_list_404_json_resp()

@type user_course_assistant_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_course_assistant_crud_list_405_json_resp()

@type user_course_assistant_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_course_instructor_crud_list_400_json_resp()

@type user_course_instructor_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_course_instructor_crud_list_403_json_resp()

@type user_course_instructor_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_course_instructor_crud_list_404_json_resp()

@type user_course_instructor_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_course_instructor_crud_list_405_json_resp()

@type user_course_instructor_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_course_learner_crud_list_400_json_resp()

@type user_course_learner_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_course_learner_crud_list_403_json_resp()

@type user_course_learner_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_course_learner_crud_list_404_json_resp()

@type user_course_learner_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_course_learner_crud_list_405_json_resp()

@type user_course_learner_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_crud_create_400_json_resp()

@type user_crud_create_400_json_resp() :: %{message: String.t() | nil}

user_crud_create_403_json_resp()

@type user_crud_create_403_json_resp() :: %{message: String.t() | nil}

user_crud_create_404_json_resp()

@type user_crud_create_404_json_resp() :: %{message: String.t() | nil}

user_crud_create_405_json_resp()

@type user_crud_create_405_json_resp() :: %{message: String.t() | nil}

user_crud_create_batch_202_json_resp()

@type user_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}

user_crud_create_batch_400_json_resp()

@type user_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}

user_crud_create_batch_403_json_resp()

@type user_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}

user_crud_create_batch_404_json_resp()

@type user_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}

user_crud_create_batch_405_json_resp()

@type user_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}

user_crud_delete_400_json_resp()

@type user_crud_delete_400_json_resp() :: %{message: String.t() | nil}

user_crud_delete_403_json_resp()

@type user_crud_delete_403_json_resp() :: %{message: String.t() | nil}

user_crud_delete_404_json_resp()

@type user_crud_delete_404_json_resp() :: %{message: String.t() | nil}

user_crud_delete_405_json_resp()

@type user_crud_delete_405_json_resp() :: %{message: String.t() | nil}

user_crud_get_400_json_resp()

@type user_crud_get_400_json_resp() :: %{message: String.t() | nil}

user_crud_get_403_json_resp()

@type user_crud_get_403_json_resp() :: %{message: String.t() | nil}

user_crud_get_404_json_resp()

@type user_crud_get_404_json_resp() :: %{message: String.t() | nil}

user_crud_get_405_json_resp()

@type user_crud_get_405_json_resp() :: %{message: String.t() | nil}

user_crud_list_400_json_resp()

@type user_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_crud_list_403_json_resp()

@type user_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_crud_list_404_json_resp()

@type user_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_crud_list_405_json_resp()

@type user_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_crud_update_400_json_resp()

@type user_crud_update_400_json_resp() :: %{message: String.t() | nil}

user_crud_update_403_json_resp()

@type user_crud_update_403_json_resp() :: %{message: String.t() | nil}

user_crud_update_404_json_resp()

@type user_crud_update_404_json_resp() :: %{message: String.t() | nil}

user_crud_update_405_json_resp()

@type user_crud_update_405_json_resp() :: %{message: String.t() | nil}

user_crud_update_batch_202_json_resp()

@type user_crud_update_batch_202_json_resp() :: %{batch_id: integer() | nil}

user_crud_update_batch_400_json_resp()

@type user_crud_update_batch_400_json_resp() :: %{message: String.t() | nil}

user_crud_update_batch_403_json_resp()

@type user_crud_update_batch_403_json_resp() :: %{message: String.t() | nil}

user_crud_update_batch_404_json_resp()

@type user_crud_update_batch_404_json_resp() :: %{message: String.t() | nil}

user_crud_update_batch_405_json_resp()

@type user_crud_update_batch_405_json_resp() :: %{message: String.t() | nil}

user_direct_report_crud_list_400_json_resp()

@type user_direct_report_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_direct_report_crud_list_403_json_resp()

@type user_direct_report_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_direct_report_crud_list_404_json_resp()

@type user_direct_report_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_direct_report_crud_list_405_json_resp()

@type user_direct_report_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_400_json_resp()

@type user_friend_crud_create_400_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_403_json_resp()

@type user_friend_crud_create_403_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_404_json_resp()

@type user_friend_crud_create_404_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_405_json_resp()

@type user_friend_crud_create_405_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_batch_202_json_resp()

@type user_friend_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}

user_friend_crud_create_batch_400_json_resp()

@type user_friend_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_batch_403_json_resp()

@type user_friend_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_batch_404_json_resp()

@type user_friend_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}

user_friend_crud_create_batch_405_json_resp()

@type user_friend_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}

user_friend_crud_delete_400_json_resp()

@type user_friend_crud_delete_400_json_resp() :: %{message: String.t() | nil}

user_friend_crud_delete_403_json_resp()

@type user_friend_crud_delete_403_json_resp() :: %{message: String.t() | nil}

user_friend_crud_delete_404_json_resp()

@type user_friend_crud_delete_404_json_resp() :: %{message: String.t() | nil}

user_friend_crud_delete_405_json_resp()

@type user_friend_crud_delete_405_json_resp() :: %{message: String.t() | nil}

user_friend_crud_list_400_json_resp()

@type user_friend_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_friend_crud_list_403_json_resp()

@type user_friend_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_friend_crud_list_404_json_resp()

@type user_friend_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_friend_crud_list_405_json_resp()

@type user_friend_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_group_admin_crud_list_400_json_resp()

@type user_group_admin_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_group_admin_crud_list_403_json_resp()

@type user_group_admin_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_group_admin_crud_list_404_json_resp()

@type user_group_admin_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_group_admin_crud_list_405_json_resp()

@type user_group_admin_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_group_assistant_crud_list_400_json_resp()

@type user_group_assistant_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_group_assistant_crud_list_403_json_resp()

@type user_group_assistant_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_group_assistant_crud_list_404_json_resp()

@type user_group_assistant_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_group_assistant_crud_list_405_json_resp()

@type user_group_assistant_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_group_leader_crud_list_400_json_resp()

@type user_group_leader_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_group_leader_crud_list_403_json_resp()

@type user_group_leader_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_group_leader_crud_list_404_json_resp()

@type user_group_leader_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_group_leader_crud_list_405_json_resp()

@type user_group_leader_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_group_member_crud_list_400_json_resp()

@type user_group_member_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_group_member_crud_list_403_json_resp()

@type user_group_member_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_group_member_crud_list_404_json_resp()

@type user_group_member_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_group_member_crud_list_405_json_resp()

@type user_group_member_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_mentee_crud_list_400_json_resp()

@type user_mentee_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_mentee_crud_list_403_json_resp()

@type user_mentee_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_mentee_crud_list_404_json_resp()

@type user_mentee_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_mentee_crud_list_405_json_resp()

@type user_mentee_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_mentor_crud_list_400_json_resp()

@type user_mentor_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_mentor_crud_list_403_json_resp()

@type user_mentor_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_mentor_crud_list_404_json_resp()

@type user_mentor_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_mentor_crud_list_405_json_resp()

@type user_mentor_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_400_json_resp()

@type user_parent_crud_create_400_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_403_json_resp()

@type user_parent_crud_create_403_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_404_json_resp()

@type user_parent_crud_create_404_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_405_json_resp()

@type user_parent_crud_create_405_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_batch_202_json_resp()

@type user_parent_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}

user_parent_crud_create_batch_400_json_resp()

@type user_parent_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_batch_403_json_resp()

@type user_parent_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_batch_404_json_resp()

@type user_parent_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}

user_parent_crud_create_batch_405_json_resp()

@type user_parent_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}

user_parent_crud_delete_400_json_resp()

@type user_parent_crud_delete_400_json_resp() :: %{message: String.t() | nil}

user_parent_crud_delete_403_json_resp()

@type user_parent_crud_delete_403_json_resp() :: %{message: String.t() | nil}

user_parent_crud_delete_404_json_resp()

@type user_parent_crud_delete_404_json_resp() :: %{message: String.t() | nil}

user_parent_crud_delete_405_json_resp()

@type user_parent_crud_delete_405_json_resp() :: %{message: String.t() | nil}

user_parent_crud_list_400_json_resp()

@type user_parent_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_parent_crud_list_403_json_resp()

@type user_parent_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_parent_crud_list_404_json_resp()

@type user_parent_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_parent_crud_list_405_json_resp()

@type user_parent_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_session_crud_list_400_json_resp()

@type user_session_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_session_crud_list_403_json_resp()

@type user_session_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_session_crud_list_404_json_resp()

@type user_session_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_session_crud_list_405_json_resp()

@type user_session_crud_list_405_json_resp() :: %{message: String.t() | nil}

user_visit_crud_list_400_json_resp()

@type user_visit_crud_list_400_json_resp() :: %{message: String.t() | nil}

user_visit_crud_list_403_json_resp()

@type user_visit_crud_list_403_json_resp() :: %{message: String.t() | nil}

user_visit_crud_list_404_json_resp()

@type user_visit_crud_list_404_json_resp() :: %{message: String.t() | nil}

user_visit_crud_list_405_json_resp()

@type user_visit_crud_list_405_json_resp() :: %{message: String.t() | nil}

Functions

user_assessment_grade_crud_get(id, grade_id, opts \\ [])

Get a user's assessment grade

Return a user's assessment grade.

Options

  • $include: Comma separated list of relationships to include in the results, taken from this list: user, grader, assessment, course.

user_assessment_grade_crud_list(id, opts \\ [])

List user assessment grades

Return a list of user assessment grades.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, id, assessment_id, course_id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, grader, assessment, course.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_child_crud_create(id, body, opts \\ [])

Add user child

Add a child to this user.

Request Body

Content Types: application/json

Here is the format of a request.

user_child_crud_create_batch(id, body, opts \\ [])

Add user children

Add up to 100 children using a batch job.

Request Body

Content Types: application/json

Here is the format of a request.

user_child_crud_delete(id, user_id, opts \\ [])

Remove user child

Remove the specified child from the user.

user_child_crud_list(id, opts \\ [])

List user children

Return a list of the user's children.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_course_assistant_crud_list(id, opts \\ [])

List user course assistants

Return a list of user course assistants.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, course.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_course_instructor_crud_list(id, opts \\ [])

List user course instructors

Return a list of user course instructors.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id, coinstructor.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, course.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_course_learner_crud_list(id, opts \\ [])

List user course learners

Return a list of user course learners.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id, enrolled_at, started, started_at, completed, completed_at, completed_by_id, unenrolled (default: false), unenrolled_at, deactivated, deactivated_at, reactivated_at, transferred, transferred_at, course_archived (default: false), user_archived (default: false), last_visited_at.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, course, progress, enrolled_by, unenrolled_by, deactivated_by, reactivated_by, transferred_by, transferred_from, transferred_to, order_item.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_crud_create(body, opts \\ [])

Create user

Create a user.

By default, a user is not notified that an account has been added for them. If you want them to receive a notification with login instructions, set the optional send_login_instructions option to true. If send_login_instructions is set to true, you can add an additional optional from_name true to send the instructions from that name. For example: POST /users?$options={"send_login_instructions": true}, Payload: {first_name: 'John', last_name: 'Smith', userid: 'jsmith', roles: 'Learner'}

Options

  • $options: Valid options are: send_login_instructions, change_password, from_name, reply_to_email

Request Body

Content Types: application/json

Here is the format of a request.

user_crud_create_batch(body, opts \\ [])

Create users

Create up to 100 users using a batch job.

By default, a user is not notified that an account has been added for them. If you want them to receive a notification with login instructions, set the optional send_login_instructions option to true. If send_login_instructions is set to true, you can add an additional optional from_name true to send the instructions from that name. For example: POST /users?$options={"send_login_instructions": true}, Payload: {first_name: 'John', last_name: 'Smith', userid: 'jsmith', roles: 'Learner'}

Options

  • $options: Valid options are: send_login_instructions, change_password, from_name, reply_to_email

Request Body

Content Types: application/json

Here is the format of a request.

user_crud_delete(id, opts \\ [])

Delete user

Delete the user with the specified ID.

user_crud_get(id, opts \\ [])

Get user

Return the user with the specified ID.

Options

  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.

user_crud_list(opts \\ [])

List users

Return a list of users. By default, users that are archived are not returned. You can provide one or more optional filters.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_crud_update(id, body, opts \\ [])

@spec user_crud_update(id :: integer(), body :: map(), opts :: keyword()) ::
  {:ok, Cyphi.User.t()}
  | {:error,
     user_crud_update_400_json_resp()
     | user_crud_update_403_json_resp()
     | user_crud_update_404_json_resp()
     | user_crud_update_405_json_resp()}

Update user

Update the specified user. Note that to archive/unarchive a user, you can simply update their archived attribute.

Request Body

Content Types: application/json

Here is the format of a request.

user_crud_update_batch(body, opts \\ [])

Update users

Update up to 100 users using a batch job. Note that to archive/unarchive a user, you can simply update their archived attribute.

Request Body

Content Types: application/json

Here is the format of a request.

user_direct_report_crud_list(id, opts \\ [])

List user direct reports

Return a list of user direct reports.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_friend_crud_create(id, body, opts \\ [])

Add user friend

Add a friend to this user.

Request Body

Content Types: application/json

Here is the format of a request.

user_friend_crud_create_batch(id, body, opts \\ [])

Add user friends

Add up to 100 friends using a batch job.

Request Body

Content Types: application/json

Here is the format of a request.

user_friend_crud_delete(id, user_id, opts \\ [])

Remove user friend

Remove the specified friend from the user.

user_friend_crud_list(id, opts \\ [])

List user friends

Return a list of the user's friends.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_group_admin_crud_list(id, opts \\ [])

List user group admins

Return Group Membership objects for each group in which this user is an admin.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, group.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_group_assistant_crud_list(id, opts \\ [])

List user group assistants

Return Group Membership objects for each group in which this user is an assistant.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, group.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_group_leader_crud_list(id, opts \\ [])

List user group leaders

Return Group Membership objects for each group in which this user is a leader.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, group.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_group_member_crud_list(id, opts \\ [])

List user group members

Return Group Membership objects for each group in which this user is a member.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user, group.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_mentee_crud_list(id, opts \\ [])

List user mentees

Return a list of the users that are mentored by this user.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_mentor_crud_list(id, opts \\ [])

List user mentors

Return a list of the user's mentors.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_parent_crud_create(id, body, opts \\ [])

Add user parent

Add a parent to this user.

Request Body

Content Types: application/json

Here is the format of a request.

user_parent_crud_create_batch(id, body, opts \\ [])

Add user parents

Add up to 100 parents using a batch job.

Request Body

Content Types: application/json

Here is the format of a request.

user_parent_crud_delete(id, user_id, opts \\ [])

Remove user parent

Remove the specified parent from the user.

user_parent_crud_list(id, opts \\ [])

List user parents

Return a list of the user's parents.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.
  • $include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
  • $order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.

user_session_crud_list(id, opts \\ [])

List user sessions

Return a list of the user's sessions.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, login_at, logout_at, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.

user_visit_crud_list(id, opts \\ [])

List user visits

Return a list of the user's visits.

Options

  • $after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.
  • $count: If true, just return the number of list items in the form {'count' : number}.
  • $filter: Filter using JSON structure, with attributes taken from this list: user_id, started_at, ended_at, id.
  • $include: Comma separated list of relationships to include in the results, taken from this list: user.
  • $limit: Limit the number of returned objects. The default is 10, the maximum is 100.
  • $offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.