Cyphi.JobTitles (Cyphi v0.1.0)
Provides API endpoints related to job titles
Summary
Functions
Create job title
Create job titles
Delete job title
Get job title
List job titles
Update job title
Update job titles
List job title users
Types
@type job_title_crud_create_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type job_title_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_delete_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_delete_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_delete_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_delete_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_get_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_get_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_get_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_get_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_405_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type job_title_crud_update_batch_400_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_batch_403_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_batch_404_json_resp() :: %{message: String.t() | nil}
@type job_title_crud_update_batch_405_json_resp() :: %{message: String.t() | nil}
@type job_title_user_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type job_title_user_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type job_title_user_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type job_title_user_crud_list_405_json_resp() :: %{message: String.t() | nil}
Functions
@spec job_title_crud_create(body :: map(), opts :: keyword()) :: {:ok, Cyphi.JobTitle.t()} | {:error, job_title_crud_create_400_json_resp() | job_title_crud_create_403_json_resp() | job_title_crud_create_404_json_resp() | job_title_crud_create_405_json_resp()}
Create job title
Create a job title.
Request Body
Content Types: application/json
Here is the format of a request.
@spec job_title_crud_create_batch(body :: [map()], opts :: keyword()) :: {:ok, job_title_crud_create_batch_202_json_resp()} | {:error, job_title_crud_create_batch_400_json_resp() | job_title_crud_create_batch_403_json_resp() | job_title_crud_create_batch_404_json_resp() | job_title_crud_create_batch_405_json_resp()}
Create job titles
Create up to 100 job titles using a batch job.
Request Body
Content Types: application/json
Here is the format of a request.
@spec job_title_crud_delete(id :: integer(), opts :: keyword()) :: :ok | {:error, job_title_crud_delete_400_json_resp() | job_title_crud_delete_403_json_resp() | job_title_crud_delete_404_json_resp() | job_title_crud_delete_405_json_resp()}
Delete job title
Delete the job title with the specified ID.
@spec job_title_crud_get(id :: integer(), opts :: keyword()) :: {:ok, Cyphi.JobTitle.t()} | {:error, job_title_crud_get_400_json_resp() | job_title_crud_get_403_json_resp() | job_title_crud_get_404_json_resp() | job_title_crud_get_405_json_resp()}
Get job title
Return the job title with the specified ID.
@spec job_title_crud_list(opts :: keyword()) :: {:ok, [Cyphi.JobTitle.t()]} | {:error, job_title_crud_list_400_json_resp() | job_title_crud_list_403_json_resp() | job_title_crud_list_404_json_resp() | job_title_crud_list_405_json_resp()}
List job titles
Return a list of job titles. You can provide one or more optional filters.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: id, name, tags.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, name. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec job_title_crud_update(id :: integer(), body :: map(), opts :: keyword()) :: {:ok, Cyphi.JobTitle.t()} | {:error, job_title_crud_update_400_json_resp() | job_title_crud_update_403_json_resp() | job_title_crud_update_404_json_resp() | job_title_crud_update_405_json_resp()}
Update job title
Update the job title with the specified ID.
Request Body
Content Types: application/json
Here is the format of a request.
@spec job_title_crud_update_batch(body :: [map()], opts :: keyword()) :: {:ok, job_title_crud_update_batch_202_json_resp()} | {:error, job_title_crud_update_batch_400_json_resp() | job_title_crud_update_batch_403_json_resp() | job_title_crud_update_batch_404_json_resp() | job_title_crud_update_batch_405_json_resp()}
Update job titles
Update up to 100 job titles using a batch job.
Request Body
Content Types: application/json
Here is the format of a request.
@spec job_title_user_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, job_title_user_crud_list_400_json_resp() | job_title_user_crud_list_403_json_resp() | job_title_user_crud_list_404_json_resp() | job_title_user_crud_list_405_json_resp()}
List job title users
List users with the specified job title. By default it lists users that are not archived.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.