Cyphi.Users (Cyphi v0.1.0)
Provides API endpoints related to users
Summary
Functions
Get a user's assessment grade
List user assessment grades
Add user child
Add user children
Remove user child
List user children
List user course assistants
List user course instructors
List user course learners
Create user
Create users
Delete user
Get user
List users
Update user
Update users
List user direct reports
Add user friend
Add user friends
Remove user friend
List user friends
List user group admins
List user group assistants
List user group leaders
List user group members
List user mentees
List user mentors
Add user parent
Add user parents
Remove user parent
List user parents
List user sessions
List user visits
Types
@type user_assessment_grade_crud_get_400_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_get_403_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_get_404_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_get_405_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_assessment_grade_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_400_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_403_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_404_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_405_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type user_child_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_delete_400_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_delete_403_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_delete_404_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_delete_405_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_child_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_course_assistant_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_course_assistant_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_course_assistant_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_course_assistant_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_course_instructor_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_course_instructor_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_course_instructor_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_course_instructor_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_course_learner_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_course_learner_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_course_learner_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_course_learner_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type user_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_delete_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_delete_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_delete_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_delete_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_get_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_get_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_get_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_get_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_405_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type user_crud_update_batch_400_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_batch_403_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_batch_404_json_resp() :: %{message: String.t() | nil}
@type user_crud_update_batch_405_json_resp() :: %{message: String.t() | nil}
@type user_direct_report_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_direct_report_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_direct_report_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_direct_report_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_400_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_403_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_404_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_405_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type user_friend_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_delete_400_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_delete_403_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_delete_404_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_delete_405_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_friend_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_group_admin_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_group_admin_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_group_admin_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_group_admin_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_group_assistant_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_group_assistant_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_group_assistant_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_group_assistant_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_group_leader_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_group_leader_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_group_leader_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_group_leader_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_group_member_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_group_member_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_group_member_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_group_member_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_mentee_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_mentee_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_mentee_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_mentee_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_mentor_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_mentor_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_mentor_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_mentor_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_400_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_403_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_404_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_405_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_batch_202_json_resp() :: %{batch_id: integer() | nil}
@type user_parent_crud_create_batch_400_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_batch_403_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_batch_404_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_create_batch_405_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_delete_400_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_delete_403_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_delete_404_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_delete_405_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_parent_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_session_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_session_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_session_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_session_crud_list_405_json_resp() :: %{message: String.t() | nil}
@type user_visit_crud_list_400_json_resp() :: %{message: String.t() | nil}
@type user_visit_crud_list_403_json_resp() :: %{message: String.t() | nil}
@type user_visit_crud_list_404_json_resp() :: %{message: String.t() | nil}
@type user_visit_crud_list_405_json_resp() :: %{message: String.t() | nil}
Functions
@spec user_assessment_grade_crud_get( id :: integer(), grade_id :: integer(), opts :: keyword() ) :: {:ok, Cyphi.Grade.t()} | {:error, user_assessment_grade_crud_get_400_json_resp() | user_assessment_grade_crud_get_403_json_resp() | user_assessment_grade_crud_get_404_json_resp() | user_assessment_grade_crud_get_405_json_resp()}
Get a user's assessment grade
Return a user's assessment grade.
Options
$include: Comma separated list of relationships to include in the results, taken from this list: user, grader, assessment, course.
@spec user_assessment_grade_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Grade.t()]} | {:error, user_assessment_grade_crud_list_400_json_resp() | user_assessment_grade_crud_list_403_json_resp() | user_assessment_grade_crud_list_404_json_resp() | user_assessment_grade_crud_list_405_json_resp()}
List user assessment grades
Return a list of user assessment grades.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, id, assessment_id, course_id.$include: Comma separated list of relationships to include in the results, taken from this list: user, grader, assessment, course.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_child_crud_create(id :: integer(), body :: map(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_child_crud_create_400_json_resp() | user_child_crud_create_403_json_resp() | user_child_crud_create_404_json_resp() | user_child_crud_create_405_json_resp()}
Add user child
Add a child to this user.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_child_crud_create_batch( id :: integer(), body :: [map()], opts :: keyword() ) :: {:ok, user_child_crud_create_batch_202_json_resp()} | {:error, user_child_crud_create_batch_400_json_resp() | user_child_crud_create_batch_403_json_resp() | user_child_crud_create_batch_404_json_resp() | user_child_crud_create_batch_405_json_resp()}
Add user children
Add up to 100 children using a batch job.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_child_crud_delete(id :: integer(), user_id :: integer(), opts :: keyword()) :: :ok | {:error, user_child_crud_delete_400_json_resp() | user_child_crud_delete_403_json_resp() | user_child_crud_delete_404_json_resp() | user_child_crud_delete_405_json_resp()}
Remove user child
Remove the specified child from the user.
@spec user_child_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_child_crud_list_400_json_resp() | user_child_crud_list_403_json_resp() | user_child_crud_list_404_json_resp() | user_child_crud_list_405_json_resp()}
List user children
Return a list of the user's children.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_course_assistant_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Assistant.t()]} | {:error, user_course_assistant_crud_list_400_json_resp() | user_course_assistant_crud_list_403_json_resp() | user_course_assistant_crud_list_404_json_resp() | user_course_assistant_crud_list_405_json_resp()}
List user course assistants
Return a list of user course assistants.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id.$include: Comma separated list of relationships to include in the results, taken from this list: user, course.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_course_instructor_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Instructor.t()]} | {:error, user_course_instructor_crud_list_400_json_resp() | user_course_instructor_crud_list_403_json_resp() | user_course_instructor_crud_list_404_json_resp() | user_course_instructor_crud_list_405_json_resp()}
List user course instructors
Return a list of user course instructors.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id, coinstructor.$include: Comma separated list of relationships to include in the results, taken from this list: user, course.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_course_learner_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Learner.t()]} | {:error, user_course_learner_crud_list_400_json_resp() | user_course_learner_crud_list_403_json_resp() | user_course_learner_crud_list_404_json_resp() | user_course_learner_crud_list_405_json_resp()}
List user course learners
Return a list of user course learners.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, course_id, id, enrolled_at, started, started_at, completed, completed_at, completed_by_id, unenrolled (default: false), unenrolled_at, deactivated, deactivated_at, reactivated_at, transferred, transferred_at, course_archived (default: false), user_archived (default: false), last_visited_at.$include: Comma separated list of relationships to include in the results, taken from this list: user, course, progress, enrolled_by, unenrolled_by, deactivated_by, reactivated_by, transferred_by, transferred_from, transferred_to, order_item.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_crud_create(body :: map(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_crud_create_400_json_resp() | user_crud_create_403_json_resp() | user_crud_create_404_json_resp() | user_crud_create_405_json_resp()}
Create user
Create a user.
By default, a user is not notified that an account has been added for them. If you want them to receive a notification with login instructions, set the optional send_login_instructions option to true. If send_login_instructions is set to true, you can add an additional optional from_name true to send the instructions from that name. For example: POST /users?$options={"send_login_instructions": true}, Payload: {first_name: 'John', last_name: 'Smith', userid: 'jsmith', roles: 'Learner'}
Options
$options: Valid options are: send_login_instructions, change_password, from_name, reply_to_email
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_crud_create_batch(body :: [map()], opts :: keyword()) :: {:ok, user_crud_create_batch_202_json_resp()} | {:error, user_crud_create_batch_400_json_resp() | user_crud_create_batch_403_json_resp() | user_crud_create_batch_404_json_resp() | user_crud_create_batch_405_json_resp()}
Create users
Create up to 100 users using a batch job.
By default, a user is not notified that an account has been added for them. If you want them to receive a notification with login instructions, set the optional send_login_instructions option to true. If send_login_instructions is set to true, you can add an additional optional from_name true to send the instructions from that name. For example: POST /users?$options={"send_login_instructions": true}, Payload: {first_name: 'John', last_name: 'Smith', userid: 'jsmith', roles: 'Learner'}
Options
$options: Valid options are: send_login_instructions, change_password, from_name, reply_to_email
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_crud_delete(id :: integer(), opts :: keyword()) :: :ok | {:error, user_crud_delete_400_json_resp() | user_crud_delete_403_json_resp() | user_crud_delete_404_json_resp() | user_crud_delete_405_json_resp()}
Delete user
Delete the user with the specified ID.
@spec user_crud_get(id :: integer(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_crud_get_400_json_resp() | user_crud_get_403_json_resp() | user_crud_get_404_json_resp() | user_crud_get_405_json_resp()}
Get user
Return the user with the specified ID.
Options
$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.
@spec user_crud_list(opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_crud_list_400_json_resp() | user_crud_list_403_json_resp() | user_crud_list_404_json_resp() | user_crud_list_405_json_resp()}
List users
Return a list of users. By default, users that are archived are not returned. You can provide one or more optional filters.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_crud_update(id :: integer(), body :: map(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_crud_update_400_json_resp() | user_crud_update_403_json_resp() | user_crud_update_404_json_resp() | user_crud_update_405_json_resp()}
Update user
Update the specified user. Note that to archive/unarchive a user, you can simply update their archived attribute.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_crud_update_batch(body :: [map()], opts :: keyword()) :: {:ok, user_crud_update_batch_202_json_resp()} | {:error, user_crud_update_batch_400_json_resp() | user_crud_update_batch_403_json_resp() | user_crud_update_batch_404_json_resp() | user_crud_update_batch_405_json_resp()}
Update users
Update up to 100 users using a batch job. Note that to archive/unarchive a user, you can simply update their archived attribute.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_direct_report_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_direct_report_crud_list_400_json_resp() | user_direct_report_crud_list_403_json_resp() | user_direct_report_crud_list_404_json_resp() | user_direct_report_crud_list_405_json_resp()}
List user direct reports
Return a list of user direct reports.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_friend_crud_create(id :: integer(), body :: map(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_friend_crud_create_400_json_resp() | user_friend_crud_create_403_json_resp() | user_friend_crud_create_404_json_resp() | user_friend_crud_create_405_json_resp()}
Add user friend
Add a friend to this user.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_friend_crud_create_batch( id :: integer(), body :: [map()], opts :: keyword() ) :: {:ok, user_friend_crud_create_batch_202_json_resp()} | {:error, user_friend_crud_create_batch_400_json_resp() | user_friend_crud_create_batch_403_json_resp() | user_friend_crud_create_batch_404_json_resp() | user_friend_crud_create_batch_405_json_resp()}
Add user friends
Add up to 100 friends using a batch job.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_friend_crud_delete( id :: integer(), user_id :: integer(), opts :: keyword() ) :: :ok | {:error, user_friend_crud_delete_400_json_resp() | user_friend_crud_delete_403_json_resp() | user_friend_crud_delete_404_json_resp() | user_friend_crud_delete_405_json_resp()}
Remove user friend
Remove the specified friend from the user.
@spec user_friend_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_friend_crud_list_400_json_resp() | user_friend_crud_list_403_json_resp() | user_friend_crud_list_404_json_resp() | user_friend_crud_list_405_json_resp()}
List user friends
Return a list of the user's friends.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_group_admin_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.GroupMembership.t()]} | {:error, user_group_admin_crud_list_400_json_resp() | user_group_admin_crud_list_403_json_resp() | user_group_admin_crud_list_404_json_resp() | user_group_admin_crud_list_405_json_resp()}
List user group admins
Return Group Membership objects for each group in which this user is an admin.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.$include: Comma separated list of relationships to include in the results, taken from this list: user, group.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_group_assistant_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.GroupMembership.t()]} | {:error, user_group_assistant_crud_list_400_json_resp() | user_group_assistant_crud_list_403_json_resp() | user_group_assistant_crud_list_404_json_resp() | user_group_assistant_crud_list_405_json_resp()}
List user group assistants
Return Group Membership objects for each group in which this user is an assistant.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.$include: Comma separated list of relationships to include in the results, taken from this list: user, group.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_group_leader_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.GroupMembership.t()]} | {:error, user_group_leader_crud_list_400_json_resp() | user_group_leader_crud_list_403_json_resp() | user_group_leader_crud_list_404_json_resp() | user_group_leader_crud_list_405_json_resp()}
List user group leaders
Return Group Membership objects for each group in which this user is a leader.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.$include: Comma separated list of relationships to include in the results, taken from this list: user, group.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_group_member_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.GroupMembership.t()]} | {:error, user_group_member_crud_list_400_json_resp() | user_group_member_crud_list_403_json_resp() | user_group_member_crud_list_404_json_resp() | user_group_member_crud_list_405_json_resp()}
List user group members
Return Group Membership objects for each group in which this user is a member.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, group_id, id.$include: Comma separated list of relationships to include in the results, taken from this list: user, group.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_mentee_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_mentee_crud_list_400_json_resp() | user_mentee_crud_list_403_json_resp() | user_mentee_crud_list_404_json_resp() | user_mentee_crud_list_405_json_resp()}
List user mentees
Return a list of the users that are mentored by this user.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_mentor_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_mentor_crud_list_400_json_resp() | user_mentor_crud_list_403_json_resp() | user_mentor_crud_list_404_json_resp() | user_mentor_crud_list_405_json_resp()}
List user mentors
Return a list of the user's mentors.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_parent_crud_create(id :: integer(), body :: map(), opts :: keyword()) :: {:ok, Cyphi.User.t()} | {:error, user_parent_crud_create_400_json_resp() | user_parent_crud_create_403_json_resp() | user_parent_crud_create_404_json_resp() | user_parent_crud_create_405_json_resp()}
Add user parent
Add a parent to this user.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_parent_crud_create_batch( id :: integer(), body :: [map()], opts :: keyword() ) :: {:ok, user_parent_crud_create_batch_202_json_resp()} | {:error, user_parent_crud_create_batch_400_json_resp() | user_parent_crud_create_batch_403_json_resp() | user_parent_crud_create_batch_404_json_resp() | user_parent_crud_create_batch_405_json_resp()}
Add user parents
Add up to 100 parents using a batch job.
Request Body
Content Types: application/json
Here is the format of a request.
@spec user_parent_crud_delete( id :: integer(), user_id :: integer(), opts :: keyword() ) :: :ok | {:error, user_parent_crud_delete_400_json_resp() | user_parent_crud_delete_403_json_resp() | user_parent_crud_delete_404_json_resp() | user_parent_crud_delete_405_json_resp()}
Remove user parent
Remove the specified parent from the user.
@spec user_parent_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.User.t()]} | {:error, user_parent_crud_list_400_json_resp() | user_parent_crud_list_403_json_resp() | user_parent_crud_list_404_json_resp() | user_parent_crud_list_405_json_resp()}
List user parents
Return a list of the user's parents.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: organization_id, job_title_id, manager_id, added_by_id, id, userid, first_name, last_name, roles, email, mobile_phone, learnerID, instructorID, joined_at, last_login_at, sis_id, sis_pid, archived (default: false), tags.$include: Comma separated list of relationships to include in the results, taken from this list: organization, archiver, job_title, manager, added_by.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.$order: Comma separated attribute names to sort by, taken from this list: id, userid, first_name, last_name, email, learnerID, instructorID, sis_id, sis_pid. Add :desc to the end of an attribute name for descending order. This cannot be used with the $after parameter.
@spec user_session_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Session.t()]} | {:error, user_session_crud_list_400_json_resp() | user_session_crud_list_403_json_resp() | user_session_crud_list_404_json_resp() | user_session_crud_list_405_json_resp()}
List user sessions
Return a list of the user's sessions.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, login_at, logout_at, id.$include: Comma separated list of relationships to include in the results, taken from this list: user.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.
@spec user_visit_crud_list(id :: integer(), opts :: keyword()) :: {:ok, [Cyphi.Visit.t()]} | {:error, user_visit_crud_list_400_json_resp() | user_visit_crud_list_403_json_resp() | user_visit_crud_list_404_json_resp() | user_visit_crud_list_405_json_resp()}
List user visits
Return a list of the user's visits.
Options
$after: Used for fast paging by setting the value to the last object id. This cannot be used with the $order parameter.$count: If true, just return the number of list items in the form {'count' : number}.$filter: Filter using JSON structure, with attributes taken from this list: user_id, started_at, ended_at, id.$include: Comma separated list of relationships to include in the results, taken from this list: user.$limit: Limit the number of returned objects. The default is 10, the maximum is 100.$offset: Used for paging through a small dataset, and it can be used with the $order parameter. This cannot be used with the $after parameter.